@@ -11,6 +11,12 @@ my $chart = VS::Chart->new(
     line_width => 1,
     y_label_fmt => "%d %%",
     x_ticks => 1,
+    labels_font_face => "foo",
+    labels_font_weight => "normal",
+    labels_font_slant => "italic",
+    labels_font_size => 11,
+    title   => "black",
+    title_font_size => 36,
 );
 
 $chart->add(Date::Simple->new("2000-01-01"), 20);
